@@ -582,9 +582,6 @@ def _validate_roles(roles, stackname='overcloud'):
         if 'name' in defaults:
             raise ValueError("%s: cannot specify name in defaults"
                              % name)
-        if 'provisioned' in defaults:
-            raise ValueError("%s: cannot specify provisioned in defaults"
-                             % name)
         if 'instances' in item:
             _validate_instances(item['instances'])
 
