@@ -12,7 +12,6 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import tempfile
 
 from glanceclient.v2 import client as glanceclient
 from heatclient.v1 import client as heatclient
@@ -28,7 +27,6 @@ from swiftclient import service as swift_service
 from zaqarclient.queues.v2 import client as zaqarclient
 
 from tripleo_common.utils import keystone as keystone_utils
-from tripleo_common.utils import tarball
 
 
 class TripleOAction(actions.Action):
@@ -178,19 +176,3 @@ class TripleOAction(actions.Action):
         )
 
         return nova_client(2, **conf)
-
-
-class UploadDirectoryAction(TripleOAction):
-    """Upload a directory to Swift."""
-    def __init__(self, container, dir_to_upload):
-        super(UploadDirectoryAction, self).__init__()
-        self.container = container
-        self.dir_to_upload = dir_to_upload
-
-    def run(self, context):
-        with tempfile.NamedTemporaryFile() as tmp_tarball:
-            tarball.create_tarball(self.dir_to_upload, tmp_tarball.name)
-            tarball.tarball_extract_to_swift_container(
-                self.get_object_client(context),
-                tmp_tarball.name,
-                self.container)
