@@ -24,12 +24,12 @@ from mistral_lib import actions
 from swiftclient import exceptions as swiftexceptions
 
 from tripleo_common.actions import base
-from tripleo_common.actions import templates
 from tripleo_common import constants
 from tripleo_common import update
 from tripleo_common.utils import overcloudrc
 from tripleo_common.utils import plan as plan_utils
 from tripleo_common.utils import swift as swiftutils
+from tripleo_common.utils import template as template_utils
 
 LOG = logging.getLogger(__name__)
 
@@ -156,6 +156,8 @@ class DeployStackAction(base.TripleOAction):
         parameters = dict()
         if not self.skip_deploy_identifier:
             parameters['DeployIdentifier'] = int(time.time())
+        else:
+            parameters['DeployIdentifier'] = ''
         parameters['UpdateIdentifier'] = ''
         parameters['StackAction'] = 'CREATE' if stack_is_new else 'UPDATE'
 
@@ -192,16 +194,10 @@ class DeployStackAction(base.TripleOAction):
                 return actions.Result(error=err_msg)
 
         # process all plan files and create or update a stack
-        process_templates_action = templates.ProcessTemplatesAction(
-            container=self.container
+        processed_data = template_utils.process_templates(
+            swift, heat, container=self.container,
+            prune_services=True
         )
-        processed_data = process_templates_action.run(context)
-
-        # If we receive a 'Result' instance it is because the parent action
-        # had an error.
-        if isinstance(processed_data, actions.Result):
-            return processed_data
-
         stack_args = processed_data.copy()
         stack_args['timeout_mins'] = self.timeout_mins
 
@@ -434,29 +430,3 @@ class DeploymentStatusAction(base.TripleOAction):
                     deployment_status=deployment_status,
                     ansible_status=ansible_status,
                     status_update=status_update)
-
-
-class ConvertStatusAction(base.TripleOAction):
-    """Translate a Heat stack status into a config-download deployment status
-
-    """
-
-    def __init__(self, status):
-        super(ConvertStatusAction, self).__init__()
-        self.status = status
-
-    def run(self, context):
-        matrix = {
-            'NO_STACK': 'UNDEPLOYED',
-            'CREATE_IN_PROGRESS': 'DEPLOYING',
-            'CREATE_COMPLETE': 'DEPLOY_SUCCESS',
-            'CREATE_FAILED': 'DEPLOY_FAILED',
-            'DELETE_COMPLETE': 'UNDEPLOYED',
-            'DELETE_IN_PROGRESS': 'UNDEPLOYING',
-            'DELETE_FAILED': 'UNDEPLOY_FAILED',
-            'UPDATE_IN_PROGRESS': 'DEPLOYING',
-            'UPDATE_FAILED': 'DEPLOY_FAILED',
-            'UPDATE_COMPLETE': 'DEPLOY_SUCCESS'
-        }
-
-        return matrix.get(self.status, 'UNKNOWN')
