@@ -82,6 +82,8 @@ MEDIA_TYPES = (
     MEDIA_MANIFEST_V1_SIGNED,
     MEDIA_MANIFEST_V2,
     MEDIA_MANIFEST_V2_LIST,
+    MEDIA_OCI_MANIFEST_V1,
+    MEDIA_OCI_INDEX_V1,
     MEDIA_CONFIG,
     MEDIA_BLOB,
     MEDIA_BLOB_COMPRESSED
@@ -90,6 +92,8 @@ MEDIA_TYPES = (
     'application/vnd.docker.distribution.manifest.v1+prettyjws',
     'application/vnd.docker.distribution.manifest.v2+json',
     'application/vnd.docker.distribution.manifest.list.v2+json',
+    'application/vnd.oci.image.manifest.v1+json',
+    'application/vnd.oci.image.index.v1+json',
     'application/vnd.docker.container.image.v1+json',
     'application/vnd.docker.image.rootfs.diff.tar',
     'application/vnd.docker.image.rootfs.diff.tar.gzip'
@@ -1799,8 +1803,16 @@ class PythonImageUploader(BaseImageUploader):
             else:
                 manifest_type = MEDIA_MANIFEST_V1
         else:
-            manifest_type = manifest.get(
-                'mediaType', MEDIA_MANIFEST_V2)
+            # NOTE(mwhahaha): always force docker media format if not set or
+            # is explicitly OCI because buildah uses OCI by default but we
+            # convert the metadata to Docker format in the uploader.
+            # See LP#1860585
+            manifest_type = manifest.get('mediaType', False)
+            if not manifest_type or manifest_type == MEDIA_OCI_MANIFEST_V1:
+                manifest_type = MEDIA_MANIFEST_V2
+            elif manifest_type == MEDIA_OCI_INDEX_V1:
+                manifest_type = MEDIA_MANIFEST_V2_LIST
+            manifest['mediaType'] = manifest_type
             manifest_str = json.dumps(manifest, indent=3)
 
         export = target_url.netloc in cls.export_registries
@@ -2102,13 +2114,7 @@ class PythonImageUploader(BaseImageUploader):
 
         name = '%s%s' % (source_url.netloc, source_url.path)
         image, manifest, config_str = cls._image_manifest_config(name)
-        all_layers = cls._containers_json('overlay-layers', 'layers.json')
-        layers_by_digest = {}
-        for l in all_layers:
-            if 'diff-digest' in l:
-                layers_by_digest[l['diff-digest']] = l
-            if 'compressed-diff-digest' in l:
-                layers_by_digest[l['compressed-diff-digest']] = l
+        layers_by_digest = cls._get_all_local_layers_by_digest()
 
         # Upload all layers
         copy_jobs = []
@@ -2168,6 +2174,50 @@ class PythonImageUploader(BaseImageUploader):
     def _containers_json(cls, *path):
         return json.loads(cls._containers_file(*path))
 
+    @classmethod
+    def _get_all_local_layers_by_digest(cls):
+        all_layers = cls._containers_json('overlay-layers', 'layers.json')
+        layers_by_digest = {}
+        for l in all_layers:
+            if 'diff-digest' in l:
+                layers_by_digest[l['diff-digest']] = l
+            if 'compressed-diff-digest' in l:
+                layers_by_digest[l['compressed-diff-digest']] = l
+        return layers_by_digest
+
+    @classmethod
+    def _get_local_layers_manifest(cls, manifest, config_str):
+        """Return a valid local manifest
+
+        The manifest that is kept in the container storage is the
+        original manifest but the layers may be different once processed
+        by libpod & company. We want a valid manifest for the local
+        file system so we need to use the root fs layers from the container
+        config rather than just assuming the original manifest is still
+        valid.
+        """
+        layers = cls._get_all_local_layers_by_digest()
+        config = json.loads(config_str)
+        rootfs = config.get('rootfs', {})
+        layer_ids = rootfs.get('diff_ids', None)
+        if not layer_ids:
+            # TODO(aschultz): add container name/path
+            LOG.warning('Container missing rootfs layers')
+            return manifest
+        # clear out the manifest layers
+        manifest['layers'] = []
+        for layer in layer_ids:
+            layer_digest = {'mediaType': MEDIA_BLOB}
+            if layer not in layers:
+                raise ImageNotFoundException('Unable to find layer %s in the '
+                                             'local layers' % layer)
+            layer_digest['digest'] = layer
+            # podman currently doesn't do compressed layers so just use
+            # the diff-size
+            layer_digest['size'] = layers[layer]['diff-size']
+            manifest['layers'].append(layer_digest)
+        return manifest
+
     @classmethod
     def _image_manifest_config(cls, name):
         image = None
@@ -2189,6 +2239,7 @@ class PythonImageUploader(BaseImageUploader):
             six.b(config_digest)).decode("utf-8")
         config_str = cls._containers_file('overlay-images', image_id,
                                           config_id)
+        manifest = cls._get_local_layers_manifest(manifest, config_str)
         manifest['config']['size'] = len(config_str)
         manifest['config']['mediaType'] = MEDIA_CONFIG
         return image, manifest, config_str
